Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7830)

Unified Diff: ash/wm/workspace/workspace.h

Issue 16093036: Do not create a workspace for a maximized window. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix test failure Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/wm/frame_painter_unittest.cc ('k') | ash/wm/workspace/workspace.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/wm/workspace/workspace.h
diff --git a/ash/wm/workspace/workspace.h b/ash/wm/workspace/workspace.h
index 0ad230b1265ae4530d1d6099d71986ad0ca41ee6..4b8423b48096b0712155c3d8deff53bd52838d90 100644
--- a/ash/wm/workspace/workspace.h
+++ b/ash/wm/workspace/workspace.h
@@ -26,14 +26,14 @@ class WorkspaceEventHandler;
class WorkspaceLayoutManager;
class WorkspaceManager;
// Workspace is used to maintain either a single maximized windows (including
// transients and other windows) or any number of windows (for the
// desktop). Workspace is used by WorkspaceManager to manage a set of windows.
class ASH_EXPORT Workspace {
public:
Workspace(WorkspaceManager* manager,
aura::Window* parent,
- bool is_maximized);
+ bool is_fullscreen);
~Workspace();
// Returns the topmost activatable window. This corresponds to the most
@@ -43,7 +43,7 @@ class ASH_EXPORT Workspace {
// Resets state. This should be used before destroying the Workspace.
aura::Window* ReleaseWindow();
- bool is_maximized() const { return is_maximized_; }
+ bool is_fullscreen() const { return is_fullscreen_; }
aura::Window* window() { return window_; }
@@ -60,16 +60,16 @@ class ASH_EXPORT Workspace {
WorkspaceManager* workspace_manager() { return workspace_manager_; }
// Returns true if the Workspace should be moved to pending. This is true
- // if there are no visible maximized windows.
+ // if there are no visible fullscreen windows.
bool ShouldMoveToPending() const;
- // Returns the number of maximized windows (including minimized windows that
- // would be maximized on restore). This does not consider visibility.
- int GetNumMaximizedWindows() const;
+ // Returns the number of fullscreen windows (including minimized windows that
+ // would be fullscreen on restore). This does not consider visibility.
+ int GetNumFullscreenWindows() const;
private:
- // Is this a workspace for maximized windows?
- const bool is_maximized_;
+ // Is this a workspace for fullscreen windows?
+ const bool is_fullscreen_;
WorkspaceManager* workspace_manager_;
« no previous file with comments | « ash/wm/frame_painter_unittest.cc ('k') | ash/wm/workspace/workspace.cc » ('j') | no next file with comments »
@@ -26,14 +26,14 @@ class WorkspaceEventHandler;
class WorkspaceLayoutManager;
class WorkspaceManager;
-// Workspace is used to maintain either a single maximized windows (including
+// Workspace is used to maintain either a single fullscreen windows (including
// transients and other windows) or any number of windows (for the
// desktop). Workspace is used by WorkspaceManager to manage a set of windows.

Powered by Google App Engine
This is Rietveld 408576698